# Copyright (C) 2012-2013  Peter Hatina <phatina@redhat.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

import pywbem
from lmi_client_base import LmiBaseClient
from lmi_client_base import LmiReturnValue

class LmiPowerClient(LmiBaseClient):
    POWER_CLASS_NAME = "LMI_PowerManagementService"
    POWER_STATE_SUSPEND = 4
    POWER_STATE_FORCE_REBOOT = 5
    POWER_STATE_HIBERNATE = 7
    POWER_STATE_FORCE_POWEROFF = 8
    POWER_STATE_POWEROFF = 12
    POWER_STATE_REBOOT = 15

    def __init__(self, hostname, username = "", password = ""):
        super(self.__class__, self).__init__(hostname, username, password)

    def __power_call_method(self, method, **params):
        (inst, rparams, errorstr) = self._get_instances(LmiPowerClient.POWER_CLASS_NAME)
        if not inst:
            return LmiReturnValue(rval = False, rparams = {}, errorstr = errorstr)
        (rval, rparams, errorstr) = self._call_method_raw(inst[0], method, **params)
        return LmiReturnValue(rval = rval in (0, 4096), rparams = rparams, errorstr = "")

    def poweroff(self):
        return self.__power_call_method("RequestPowerStateChange",
            PowerState=pywbem.Uint16(LmiPowerClient.POWER_STATE_POWEROFF))

    def reboot(self):
        return self.__power_call_method("RequestPowerStateChange",
            PowerState=pywbem.Uint16(LmiPowerClient.POWER_STATE_REBOOT))

    def suspend(self):
        return self.__power_call_method("RequestPowerStateChange",
            PowerState=pywbem.Uint16(LmiPowerClient.POWER_STATE_SUSPEND))

    def hibernate(self):
        return self.__power_call_method("RequestPowerStateChange",
            PowerState=pywbem.Uint16(LmiPowerClient.POWER_STATE_HIBERNATE))
