# Copyright (C) 2012-2013  Peter Hatina <phatina@redhat.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

import pywbem
from lmi_client_base import LmiBaseClient
from lmi_client_base import LmiReturnValue

class LmiService(object):
    def __init__(self, client, inst):
        self._client = client
        self._instance = inst

    def start(self):
        return self._client.service_start(self._instance)

    def stop(self):
        return self._client.service_stop(self._instance)

    def restart(self):
        return self._client.service_restart(self._instance)

    def enable(self):
        return self._client.service_enable(self._instance)

    def disable(self):
        return self._client.service_disable(self._instance)

    def reload(self):
        return self._client.service_reload(self._instance)

    def try_restart(self):
        return self._client.service_try_restart(self._instance)

    def cond_restart(self):
        return self._client.service_cond_restart(self._instance)

    def reload_restart(self):
        return self._client.service_reload_restart(self._instance)

    def reload_try_restart(self):
        return self._client.service_reload_try_restart(self._instance)

    def status(self):
        return self._client.service_status(self._instance)

class LmiServiceClient(LmiBaseClient):
    SERVICE_CLASS_NAME = "LMI_Service"

    def __init__(self, hostname, username = "", password = ""):
        super(self.__class__, self).__init__(hostname, username, password)

    def __service_get_instance(self, service):
        (inst, rparams, errorstr) = self._get_instances(
            LmiServiceClient.SERVICE_CLASS_NAME, value=service)
        if not inst:
            return LmiReturnValue(rval = None, rparams = {}, errorstr = errorstr)
        return LmiReturnValue(rval = inst[0], rparams = rparams, errorstr = "")

    def __service_call_method(self, service, method):
        (inst, rparams, errorstr) = self.__service_get_instance(service) if type(service) == str else (service, {}, "")
        if not inst:
            return LmiReturnValue(rval = False, rparams = {}, errorstr = errorstr)
        return self._call_method(inst, method)

    def __service_get_property(self, service, prop):
        (inst, _, errorstr) = self.__service_get_instance(service) if type(service) == str else (service, {}, "")
        if not inst or not prop in inst:
            return LmiReturnValue(rval = None, rparams = {}, errorstr = errorstr)
        return LmiReturnValue(rval = True, rparams = { "Message" : inst[prop] }, errorstr = "")

    def service_find(self, service):
        (inst, rparams, errorstr) = self.__service_get_instance(service)
        if not inst:
            return LmiReturnValue(rval = None, rparams = {}, errorstr = errorstr)
        return LmiReturnValue(rval = LmiService(self, inst), rparams = rparams, errorstr = "")

    def service_start(self, service):
        return self.__service_call_method(service, "StartService")

    def service_stop(self, service):
        return self.__service_call_method(service, "StopService")

    def service_restart(self, service):
        return self.__service_call_method(service, "RestartService")

    def service_enable(self, service):
        return self.__service_call_method(service, "TurnServiceOn")

    def service_disable(self, service):
        return self.__service_call_method(service, "TurnServiceOff")

    def service_reload(self, service):
        return self.__service_call_method(service, "ReloadService")

    def service_try_restart(self, service):
        return self.__service_call_method(service, "TryRestartService")

    def service_cond_restart(self, service):
        return self.__service_call_method(service, "CondRestartService")

    def service_reload_restart(self, service):
        return self.__service_call_method(service, "ReloadOrRestartService")

    def service_reload_try_restart(self, service):
        return self.__service_call_method(service, "ReloadOrTryRestartService")

    def service_status(self, service):
        return self.__service_get_property(service, "Status")
