# Copyright (C) 2012-2013  Peter Hatina <phatina@redhat.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

import sys
import optparse

class LmiBasicOptions(object):
    def __init__(self, epil = ""):
        optparse.OptionParser.format_epilog = lambda self, formatter: self.epilog
        self._parser = optparse.OptionParser(
            add_help_option = False,
            epilog = epil)
        self._parser.add_option("", "--help",
            action="help",
            help = "print this message")
        self._parser.add_option("-h", "--hostname",
            action = "store",
            dest = "hostname",
            help = "remote machine hostname")
        self._parser.add_option("-u", "--username",
            action = "store",
            dest = "username",
            help = "remote machine username")
        self._parser.add_option("-p", "--password",
            action = "store",
            dest = "password",
            help = "remote machine password")

    def parse(self, argv):
        (self._options, self._pos_options) = self._parser.parse_args(argv[1:])

    def print_help(self):
        self._parser.print_help()

    def print_wrong_usage(self):
        sys.stderr.write("Wrong tool usage!\n\n")
        self.print_help()

    @property
    def good(self):
        return len(self._pos_options) == 0

    @property
    def hostname(self):
        return self._options.hostname if self._options.hostname else ""

    @property
    def username(self):
       return self._options.username if self._options.username else ""

    @property
    def password(self):
        return self._options.password if self._options.password else ""
